Coverage for C:\src\imod-python\imod\flow\ghb.py: 100%

1 from imod.flow.pkgbase import BoundaryCondition

2

3

4 class GeneralHeadBoundary(BoundaryCondition):

5 """

6 The General-Head Boundary package is used to simulate head-dependent flux

7 boundaries. In the General-Head Boundary package the flux is always

8 proportional to the difference in head.

9

10 Parameters

11 ----------

12 head: float or xr.DataArray of floats

13 head value for the GHB (BHEAD), dims ``("layer", "y", "x")``.

14 conductance: float or xr.DataArray of floats

15 the conductance of the GHB (COND), dims ``("layer", "y", "x")``.

16 """

17

18 _pkg_id = "ghb"

19 _variable_order = ["conductance", "head"]

20

21 def __init__(self, conductance, head):

22 super().__init__()

23 self.dataset["conductance"] = conductance

24 self.dataset["head"] = head